@@ -26,6 +26,7 @@ Changelog:
 Modifications for WebSVN:
    The main description link wasn't put through htmlspecialcharacters
    Output encoding now defined by $config
+   Remove hardcoded time zone
 
 v1.6    05-10-04
     added stylesheet to RSS 1.0 feeds
@@ -117,17 +118,12 @@ while ($data = mysql_fetch_object($res)) {
 // MBOX, OPML, ATOM0.3
 echo $rss->saveFeed("RSS1.0", "news/feed.xml");
 
+# }}}
 
 ***************************************************************************
 *          A little setup                                                 *
 **************************************************************************/
 
-// your local timezone, set to "" to disable or for GMT
-define("TIME_ZONE","+01:00");
-
-
-
-
 /**
 * Version string.
 **/
@@ -142,6 +138,8 @@ define("FEEDCREATOR_VERSION", "FeedCreator 1.6");
 * @since 1.3
 */
 class FeedItem {
+    # {{{ Properties
+
     /**
      * Mandatory attributes of an item.
      */
@@ -179,6 +177,8 @@ class FeedItem {
 
     // on hold
     // var $source;
+
+    # }}}
 }
 
 
@@ -189,6 +189,8 @@ class FeedItem {
 * @since 1.3
 */
 class FeedImage {
+    # {{{ Properties
+
     /**
      * Mandatory attributes of an image.
      */
@@ -198,6 +200,8 @@ class FeedImage {
      * Optional attributes of an image.
      */
     var $width, $height, $description;
+
+    # }}}
 }
 
 
@@ -213,6 +217,7 @@ class FeedImage {
 class UniversalFeedCreator extends FeedCreator {
     var $_feed;
     
+    # {{{ _setFormat
     function _setFormat($format) {
         switch (strtoupper($format)) {
             
@@ -262,7 +267,9 @@ class UniversalFeedCreator extends FeedCreator {
             }
         }
     }
+    # }}}
     
+    # {{{ createFeed
     /**
      * Creates a syndication feed based on the items previously added.
      *
@@ -275,9 +282,9 @@ class UniversalFeedCreator extends FeedCreator {
         $this->_setFormat($format);
         return $this->_feed->createFeed();
     }
-    
-    
-    
+    # }}}
+
+    # {{{ saveFeed
     /**
      * Saves this feed as a file on the local disk. After the file is saved, an HTTP redirect
      * header may be sent to redirect the use to the newly created file.
@@ -292,6 +299,7 @@ class UniversalFeedCreator extends FeedCreator {
         $this->_setFormat($format);
         $this->_feed->saveFeed($filename, $displayContents);
     }
+    # }}}
 
 }
 
@@ -305,33 +313,34 @@ class UniversalFeedCreator extends FeedCreator {
 * @since 1.4
 */
 class FeedCreator {
+    # {{{ Properties
 
     /**
      * Mandatory attributes of a feed.
      */
     var $title, $description, $link;
-    
-    
+
+
     /**
      * Optional attributes of a feed.
      */
     var $syndicationURL, $image, $language, $copyright, $pubDate, $lastBuildDate, $editor, $editorEmail, $webmaster, $category, $docs, $ttl, $rating, $skipHours, $skipDays;
-    
-    
+
+
     /**
      * @access private
      */
     var $items = Array();
-    
-    
+
+
     /**
      * This feed's MIME content type.
      * @since 1.4
      * @access private
      */
     var $contentType = "text/xml";
-    
-    
+
+
     /**
      * Any additional elements to include as an assiciated array. All $key => $value pairs
      * will be included unencoded in the feed in the form
@@ -341,8 +350,10 @@ class FeedCreator {
      * the FeedCreator class used.
      */
     var $additionalElements = Array();
-   
+
+    # }}}
     
+    # {{{ addItem
     /**
      * Adds an FeedItem to the feed.
      *
@@ -352,8 +363,9 @@ class FeedCreator {
     function addItem($item) {
         $this->items[] = $item;
     }
-    
-    
+    # }}}
+
+    # {{{ iTrunc
     /**
      * Truncates a string to a certain length at the most sensible point.
      * First, if there's a '.' character near the end of the string, the string is truncated after this character.
@@ -392,8 +404,9 @@ class FeedCreator {
         return substr($string,0,$length-4)." ...";
             
     }
-    
-    
+    # }}}
+
+    # {{{ _createGeneratorComment
     /**
      * Creates a comment indicating the generator of this feed.
      * The format of this comment seems to be recognized by
@@ -402,8 +415,9 @@ class FeedCreator {
     function _createGeneratorComment() {
         return "<!-- generator=\"".FEEDCREATOR_VERSION."\" -->\n";
     }
-    
-    
+    # }}}
+
+    # {{{ _createAdditionalElements
     /**
      * Creates a string containing all additional elements specified in
      * $additionalElements.
@@ -420,8 +434,9 @@ class FeedCreator {
         }
         return $ae;
     }
-    
-    
+    # }}}
+
+    # {{{ createFeed
     /**
      * Builds the feed's text.
      * @abstract
@@ -429,7 +444,9 @@ class FeedCreator {
      */
     function createFeed() {
     }
-    
+    # }}}
+
+    # {{{ _generateFilename
     /**
      * Generate a filename for the feed cache file. The result will be $_SERVER["PHP_SELF"] with the extension changed to .xml.
      * For example:
@@ -450,8 +467,9 @@ class FeedCreator {
         $fileInfo = pathinfo($_SERVER["PHP_SELF"]);
         return substr($fileInfo["basename"],0,-(strlen($fileInfo["extension"])+1)).".xml";
     }
-    
-    
+    # }}}
+
+    # {{{ _redirect
     /**
      * @since 1.4
      * @access private
@@ -475,7 +493,9 @@ class FeedCreator {
         readfile($filename, "r");
         die();
     }
-    
+    # }}}
+
+    # {{{ useCached
     /**
      * Turns on caching and checks if there is a recent version of this feed in the cache.
      * If there is, an HTTP redirect header is sent.
@@ -495,8 +515,9 @@ class FeedCreator {
             $this->_redirect($filename);
         }
     }
-    
-    
+    # }}}
+
+    # {{{ saveFeed
     /**
      * Saves this feed as a file on the local disk. After the file is saved, a redirect
      * header may be sent to redirect the user to the newly created file.
@@ -520,6 +541,7 @@ class FeedCreator {
             echo "<br /><b>Error creating feed file, please check write permissions.</b><br />";
         }
     }
+    # }}}
 }
 
 
@@ -529,7 +551,8 @@ class FeedCreator {
 */
 class FeedDate {
     var $unix;
-    
+
+    # {{{ __construct
     /**
      * Creates a new instance of FeedDate representing a given date.
      * Accepts RFC 822, ISO 8601 date formats as well as unix time stamps.
@@ -581,19 +604,20 @@ class FeedDate {
         }
         $this->unix = 0;
     }
+    # }}}
 
+    # {{{ rfc822
     /**
      * Gets the date stored in this FeedDate as an RFC 822 date.
      *
      * @return a date in RFC 822 format
      */
     function rfc822() {
-        //return gmdate("r",$this->unix);
-        $date = gmdate("D, d M Y H:i:s", $this->unix);
-        if (TIME_ZONE!="") $date .= " ".str_replace(":","",TIME_ZONE);
-        return $date;
+       return gmdate("r",$this->unix);
     }
-    
+    # }}}
+
+    # {{{ iso8601
     /**
      * Gets the date stored in this FeedDate as an ISO 8601 date.
      *
@@ -602,10 +626,11 @@ class FeedDate {
     function iso8601() {
         $date = gmdate("Y-m-d\TH:i:sO",$this->unix);
         $date = substr($date,0,22) . ':' . substr($date,-2);
-        if (TIME_ZONE!="") $date = str_replace("+00:00",TIME_ZONE,$date);
         return $date;
     }
-    
+    # }}}
+
+    # {{{ unix
     /**
      * Gets the date stored in this FeedDate as unix time stamp.
      *
@@ -614,6 +639,7 @@ class FeedDate {
     function unix() {
         return $this->unix;
     }
+    # }}}
 }
 
 
@@ -626,6 +652,7 @@ class FeedDate {
 */
 class RSSCreator10 extends FeedCreator {
 
+    # {{{ createFeed
     /**
      * Builds the RSS feed's text. The feed will be compliant to RDF Site Summary (RSS) 1.0.
      * The feed will contain all items previously added in the same order.
@@ -689,6 +716,7 @@ class RSSCreator10 extends FeedCreator {
         $feed.= "</rdf:RDF>\n";
         return $feed;
     }
+    # }}}
 }
 
 
@@ -708,11 +736,14 @@ class RSSCreator091 extends FeedCreator {
      */
     var $RSSVersion;
 
+    # {{{ __construct
     function RSSCreator091() {
         $this->_setRSSVersion("0.91");
         $this->contentType = "application/rss+xml";
     }
-    
+    # }}}
+
+    # {{{ _setRSSVersion
     /**
      * Sets this RSS feed's version number.
      * @access private
@@ -720,7 +751,9 @@ class RSSCreator091 extends FeedCreator {
     function _setRSSVersion($version) {
         $this->RSSVersion = $version;
     }
+    # }}}
 
+    # {{{ createFeed
     /**
      * Builds the RSS feed's text. The feed will be compliant to RDF Site Summary (RSS) 1.0.
      * The feed will contain all items previously added in the same order.
@@ -825,6 +858,7 @@ class RSSCreator091 extends FeedCreator {
         $feed.= "</rss>\n";
         return $feed;
     }
+    # }}}
 }
 
 
@@ -838,10 +872,12 @@ class RSSCreator091 extends FeedCreator {
 */
 class RSSCreator20 extends RSSCreator091 {
 
+    # {{{ __construct
     function RSSCreator20() {
         parent::_setRSSVersion("2.0");
     }
-    
+    # }}}
+
 }
 
 
@@ -854,7 +890,8 @@ class RSSCreator20 extends RSSCreator091 {
 * @author Scott Reynen <scott@randomchaos.com> and Kai Blankenhorn <kaib@bitfolge.de>
 */
 class PIECreator01 extends FeedCreator {
-    
+
+    # {{{ createFeed
     function createFeed() {
         $feed = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
         $feed.= "<feed version=\"0.1\" xmlns=\"http://example.com/newformat#\">\n";
@@ -886,6 +923,7 @@ class PIECreator01 extends FeedCreator {
         $feed.= "</feed>\n";
         return $feed;
     }
+    # }}}
 }
 
 
@@ -907,10 +945,13 @@ class PIECreator01 extends FeedCreator {
 */
 class AtomCreator03 extends FeedCreator {
 
+    # {{{ __construct
     function AtomCreator03() {
         $this->contentType = "application/atom+xml";
     }
-    
+    # }}}
+
+    # {{{ createFeed
     function createFeed() {
         $feed = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
         $feed.= $this->_createGeneratorComment();
@@ -961,6 +1002,7 @@ class AtomCreator03 extends FeedCreator {
         $feed.= "</feed>\n";
         return $feed;
     }
+    # }}}
 }
 
 
@@ -973,10 +1015,13 @@ class AtomCreator03 extends FeedCreator {
 */
 class MBOXCreator extends FeedCreator {
 
+    # {{{ __construct
     function MBOXCreator() {
         $this->contentType = "text/plain";
     }
-    
+    # }}}
+
+    # {{{ qp_enc
     function qp_enc($input = "", $line_max = 76) {
         $hex = array('0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F');
         $lines = preg_split("/(?:\r\n|\r|\n)/", $input);
@@ -1006,8 +1051,9 @@ class MBOXCreator extends FeedCreator {
         }
         return trim($output);
     }
-    
+    # }}}
 
+    # {{{ createFeed
     /**
      * Builds the MBOX contents.
      * @return    string    the feed's complete text
@@ -1037,7 +1083,9 @@ class MBOXCreator extends FeedCreator {
         }
         return $feed;
     }
-    
+    # }}}
+
+    # {{{ _generateFilename
     /**
      * Generate a filename for the feed cache file. Overridden from FeedCreator to prevent XML data types.
      * @return string the feed cache filename
@@ -1048,6 +1096,7 @@ class MBOXCreator extends FeedCreator {
         $fileInfo = pathinfo($_SERVER["PHP_SELF"]);
         return substr($fileInfo["basename"],0,-(strlen($fileInfo["extension"])+1)).".mbox";
     }
+    # }}}
 }
 
 
@@ -1060,6 +1109,7 @@ class MBOXCreator extends FeedCreator {
 */
 class OPMLCreator extends FeedCreator {
     
+    # {{{ createFeed
     function createFeed() {     
         $feed = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
         $feed.= $this->_createGeneratorComment();
@@ -1095,6 +1145,7 @@ class OPMLCreator extends FeedCreator {
         $feed.= "</opml>\n";
         return $feed;
     }
+    # }}}
 }
 
 ?>
